// Copyright (C) 2020 Aleix Pol Gonzalez <aleixpol@kde.org>
// 2023
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#ifndef QWAYLANDXDGACTIVATIONV1_P_H
#define QWAYLANDXDGACTIVATIONV1_P_H

#include <QObject>
#include "qwayland-xdg-activation-v1.h"

#include <QtWaylandClient/QWaylandClientExtension>

class QWaylandDisplay;
class QWaylandSurface;

class QWaylandXdgActivationTokenV1
    : public QObject,
      public QtWayland::xdg_activation_token_v1
{
    Q_OBJECT
public:
    void xdg_activation_token_v1_done(const QString &token) override { Q_EMIT done(token); }

Q_SIGNALS:
    void done(const QString &token);
};

class QWaylandXdgActivationV1 : public QWaylandClientExtensionTemplate<QWaylandXdgActivationV1>,  public QtWayland::xdg_activation_v1
{
public:
    QWaylandXdgActivationV1();
    ~QWaylandXdgActivationV1() override;

    QWaylandXdgActivationTokenV1 *requestXdgActivationToken(QWaylandDisplay *display,
                                                            struct ::wl_surface *surface,
                                                            std::optional<uint32_t> serial,
                                                            const QString &app_id);
};


#endif // QWAYLANDXDGACTIVATIONV1_P_H
